starccato_sampler
-----------------

.. image:: https://coveralls.io/repos/github/starccato/starccato_sampler/badge.svg?branch=main
    :target: https://coveralls.io/github/starccato/starccato_sampler?branch=main

.. image:: https://img.shields.io/pypi/v/starccato-sampler
   :alt: PyPI - Version


Tools for parameter estimation with JAX-VAE model.


Install with:

.. code-block:: bash

    pip install starccato-sampler
